import 'package:dart_blocks/os_mobile_blocks/softcorp_client.dart';
import 'package:dart_blocks/os_mobile_blocks/user_block_cupertino/WelcomePage/welcome_page.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class UserBlockCupertino extends StatefulWidget {
  UserBlockCupertino({
    Key? key,
    required this.child,
    required this.loginLogo,
    this.createdBy,
    this.welcomeTitle,
    this.welcomeDetails,
    this.loginButtonText,
    this.welcomeLogo,
    this.registerButtonText,
    this.onLogin,
    this.emailLoginHint,
    this.passwordLoginHint,
    this.emailRegisterHint,
    this.passwordRegisterHint,
    this.loginDetails,
    this.registerDetails,
    this.primaryColor,
    this.secondaryColor,
    this.onRegister,
    this.repeatPasswordRegisterHint,
    this.loginTitle,
    this.registerTitle,
    this.textFieldBorder,
    this.registerLogo,
    this.background,
  }) : super(key: key);

  // general
  final Widget child;
  final Widget? createdBy;
  final Color? primaryColor;
  final Color? secondaryColor;
  final BoxDecoration? background;
  final Border? textFieldBorder;

  // welcome
  final Widget? welcomeLogo;
  final Widget? welcomeTitle;
  final Widget? welcomeDetails;

  // login
  final Widget? loginLogo;
  final Widget? loginButtonText;
  final Widget? loginDetails;
  final Function? onLogin;
  final String? emailLoginHint;
  final String? passwordLoginHint;
  final Widget? loginTitle;

  // register
  final Widget? registerLogo;
  final Widget? registerButtonText;
  final Widget? registerDetails;
  final Function? onRegister;
  final String? emailRegisterHint;
  final String? passwordRegisterHint;
  final String? repeatPasswordRegisterHint;
  final Widget? registerTitle;

  // on authenticated go to child;
  @override
  State<UserBlockCupertino> createState() => _UserBlockCupertinoState();
}

class _UserBlockCupertinoState extends State<UserBlockCupertino> {
  // init
  late Future<bool> isAuthenticatedFuture;

  Future<bool> getIsAuthenticated() async {
    return await SoftcorpClient.userBlock.isAuthenticated();
  }

  _UserBlockCupertinoState() {
    isAuthenticatedFuture = getIsAuthenticated();
  }

  // todo: implement no wifi connection
  @override
  Widget build(BuildContext context) {
    return CupertinoPageScaffold(
      child: FutureBuilder<bool>(
          future: isAuthenticatedFuture,
          builder: (BuildContext context, AsyncSnapshot<bool> snapshot) {
            switch (snapshot.connectionState) {
              case ConnectionState.waiting:
                return const Center(
                  child: CupertinoActivityIndicator(),
                );
              case ConnectionState.done:
                print("done" + snapshot.data.toString());
                return AnimatedSwitcher(
                  duration: const Duration(milliseconds: 500),
                  child: snapshot.data ?? false
                      ? widget.child
                      : WelcomePage(
                          textFieldBorder: widget.textFieldBorder,
                          loginLogo: widget.loginLogo ?? const SizedBox(),
                          registerLogo: widget.registerLogo ?? const SizedBox(),
                          welcomeLogo: widget.welcomeLogo ?? const SizedBox(),
                          background: widget.background ?? BoxDecoration(),
                          primaryColor: widget.primaryColor ?? Colors.black,
                          secondaryColor:
                              widget.secondaryColor ?? Colors.blueAccent,
                          welcomeDetails: widget.welcomeDetails ?? SizedBox(),
                          createdBy: widget.createdBy ?? SizedBox(),
                          welcomeTitle: widget.welcomeTitle ?? Text("Welcome"),
                          loginButtonText:
                              widget.loginButtonText ?? Text("Login"),
                          registerButtonText:
                              widget.registerButtonText ?? Text("Register"),
                          loginDetailsTitle: widget.loginDetails ?? SizedBox(),
                          onLogin: () => {
                            if (widget.onLogin != null) {widget.onLogin!()},
                            Navigator.pop(context),
                            setState(() {
                              isAuthenticatedFuture = getIsAuthenticated();
                            }),
                          },
                          loginTitle: widget.loginTitle ?? Text("Login"),
                          registerTitle:
                              widget.registerTitle ?? Text("Register"),
                          passwordLoginHint:
                              widget.passwordLoginHint ?? "Enter your password",
                          emailLoginHint:
                              widget.emailLoginHint ?? "Enter your email",
                          onRegister: widget.onRegister ?? () => {},
                          registerDetails: widget.registerDetails ?? SizedBox(),
                          passwordRegisterHint: widget.passwordRegisterHint ??
                              "Enter a password for your account",
                          repeatPasswordRegisterHint:
                              widget.repeatPasswordRegisterHint ??
                                  "Repeat your password",
                          emailRegisterHint: widget.emailRegisterHint ??
                              "Enter an email for your account",
                        ),
                );
              default:
                return Text('Error: ${snapshot.error}');
            }
          }),
    );
  }
}
